@@ -26,6 +26,8 @@ from IPython.utils import traitlets
 from IPython.utils.traitlets import (List, Unicode, CRegExp)
 
 from slurm import get_slurm_attributes
+import utils
+import lsf
 
 # if dill is available, override pickle with dill pickle
 # this lets us pickle way more things
@@ -117,8 +119,8 @@ class BcbioLSFEngineSetLauncher(launcher.LSFEngineSetLauncher):
     def start(self, n):
         self.context["cores"] = self.cores
         if self.mem:
-            # scale memory to kb
-            mem = int(float(self.mem) * 1024.0 * 1024.0)
+            lsf_unit = lsf.get_lsf_units()
+            mem = utils.convert_mb(float(self.mem) * 1024, lsf_unit)
             self.context["mem"] = "#BSUB -M %s" % mem
         else:
             self.context["mem"] = ""
@@ -757,6 +759,7 @@ def cluster_view(scheduler, queue, num_jobs, cores_per_job=1, profile=None,
         Defaults to 16 minutes. Set to longer for slow starting clusters.
       - retries: Number of retries to allow for failed tasks.
     """
+
     if extra_params is None:
         extra_params = {}
     max_delay = start_wait * 60
